@@ -89,4 +89,39 @@ def get_iou_matrix(boxes1, boxes2):
 def box2poly(box):
     x1, y1, x2, y2 = box
     poly = [x1, y1, x2, y1, x2, y2, x1, y2]
-    return poly
\ No newline at end of file
+    return poly
+
+def poly2box(poly):
+    poly = np.reshape(poly, [-1, 2])
+    box = np.concatenate([np.min(poly, axis=0), np.max(poly, axis=0)])
+    return box
+
+def nms(dets, scores, thresh):
+    dets = np.array(dets).reshape([-1, 4])
+    scores = np.array(scores).reshape([-1])
+    x1 = dets[:, 0]
+    y1 = dets[:, 1]
+    x2 = dets[:, 2]
+    y2 = dets[:, 3]
+
+    areas = (x2 - x1 + 1) * (y2 - y1 + 1)
+    order = scores.argsort()[::-1]
+
+    keep = []
+    while order.size > 0:
+        i = order[0]
+        keep.append(i)
+        xx1 = np.maximum(x1[i], x1[order[1:]])
+        yy1 = np.maximum(y1[i], y1[order[1:]])
+        xx2 = np.minimum(x2[i], x2[order[1:]])
+        yy2 = np.minimum(y2[i], y2[order[1:]])
+
+        w = np.maximum(0.0, xx2 - xx1 + 1)
+        h = np.maximum(0.0, yy2 - yy1 + 1)
+        inter = w * h
+        ovr = inter / (areas[i] + areas[order[1:]] - inter)
+
+        inds = np.where(ovr <= thresh)[0]
+        order = order[inds + 1]
+
+    return keep
